{% load i18n admin_urls jazzmin %}
{% get_jazzmin_ui_tweaks as jazzmin_ui %}

{% if has_import_permission %}
<a href='{% url opts|admin_urlname:"import" %}' class="import_link btn {{ jazzmin_ui.button_classes.secondary }}">
    <i class="fas fa-file-import"></i> {% trans "Import" %}
</a>
{% endif %}
